==> si4-request-1.0.17.tgz: package/src/index.ts <==
import axios from 'axios';
import { Errors } from './ErrorMessages';

type methods = 'GET' | 'POST' | 'UPDATE' | 'DELETE'

interface IHeader{
    headers:{
        token:string
    }
}

export async function request<R,D>(method:methods,tokenVerify:Function,token:string,url?:string,data?:D):Promise<R | any>{
    if(!url){
        throw({message:'Empty request url'})
    }else{
        const header:IHeader = {
            headers:{
                token: token
            }
        }
        await tokenVerify()
        switch(method){
            case "GET":
                return await get<R>(url,header)
            case "UPDATE":
                break;
            case "POST":
                if(data)
                    return await post<R,D>(url,header,data)
            case "DELETE":
                break;
        }
    }
}
async function get<R>(url:string,header:IHeader):Promise<R>{
    try{
        const respons = await axios.get<R,R>(url,header)
        return respons
    } catch(error){
        let errorMsg = ''
        if(!error.response){
            errorMsg = Errors.noInternet
        } else{
            if(!error.response.data.message){
                errorMsg = Errors.serverError
            } else{
                errorMsg =  error.response.data.message;
            }
        }
        throw new Error(errorMsg)
    }
}
async function post<R,D>(url:string,header:IHeader,data:D):Promise<R>{
    try{
        const respons = await axios.post<R,R>(url,data,header)
        return respons
    } catch(error){
        let errorMsg = ''
        if(!error.response){
            errorMsg = Errors.noInternet
        } else{
            if(!error.response.data.message){
                errorMsg = Errors.serverError
            } else{
                errorMsg =  error.response.data.message;
            }
        }
        throw new Error(errorMsg)
    }

}

==> si4-request-1.0.18.tgz: package/src/index.ts <==
import axios from 'axios';
import { Errors } from './ErrorMessages';

type methods = 'GET' | 'POST' | 'UPDATE' | 'DELETE'

interface IHeader{
    headers:{
        token:string
    }
}

export async function request<R,D>(method:methods,tokenVerify:()=>Promise<void>,token:string,url?:string,data?:D):Promise<R | any>{
    if(!url){
        throw({message:'Empty request url'})
    }else{
        const header:IHeader = {
            headers:{
                token: token
            }
        }
        await tokenVerify()
        switch(method){
            case "GET":
                return await get<R>(url,header)
            case "UPDATE":
                break;
            case "POST":
                if(data)
                    return await post<R,D>(url,header,data)
            case "DELETE":
                break;
        }
    }
}
async function get<R>(url:string,header:IHeader):Promise<R>{
    try{
        const respons = await axios.get<R,R>(url,header)
        return respons
    } catch(error){
        let errorMsg = ''
        if(!error.response){
            errorMsg = Errors.noInternet
        } else{
            if(!error.response.data.message){
                errorMsg = Errors.serverError
            } else{
                errorMsg =  error.response.data.message;
            }
        }
        throw new Error(errorMsg)
    }
}
async function post<R,D>(url:string,header:IHeader,data:D):Promise<R>{
    try{
        const respons = await axios.post<R,R>(url,data,header)
        return respons
    } catch(error){
        let errorMsg = ''
        if(!error.response){
            errorMsg = Errors.noInternet
        } else{
            if(!error.response.data.message){
                errorMsg = Errors.serverError
            } else{
                errorMsg =  error.response.data.message;
            }
        }
        throw new Error(errorMsg)
    }

}
